# Test Workflow

This reproduces a typical project setup with a directory per task and a top-level 
WDL file with a workflow composing those tasks. The test data are stored remotely 
as well which will test localization of the data for the workflow.

This also introduces WDL 1.0.
